@@ -193,9 +193,14 @@ class Connector(connector.SQLConnector):
 
     # https://cloud.google.com/bigquery/docs/exporting-data
     # https://cloud.google.com/bigquery/docs/reference/standard-sql/other-statements#export_data_statement
-    def _export(self, query, fmt):
+    def _export(self, query, fmt, row_limit=None):
         if fmt != formats.CSV:
             raise errors.UnsupportedFormatError(fmt)
+        if row_limit is not None:
+            rowcount_job = self.bigquery.query(f"SELECT COUNT(*) AS num_rows FROM ({query});")
+            returned_rows = next(rowcount_job.result())["num_rows"]
+            if returned_rows > row_limit:
+                raise errors.RowLimitExceeded(row_limit, returned_rows)
 
         bucket = gcp.gcs_bucket()
 
